OC.L10N.register(
    "core",
    {
    "Please select a file." : "გთხოვთ აირჩიოთ ფაილი.",
    "File is too big" : "ფაილი ზედმეტად დიდია",
    "The selected file is not an image." : "არცეული ფაილი არაა სურათი.",
    "The selected file cannot be read." : "არჩეული ფაილი არ იკითხება.",
    "Invalid file provided" : "არასწორი ფაილი",
    "No image or file provided" : "არ არის სურათი ან ფაილი",
    "Unknown filetype" : "ამოუცნობი ფაილის ტიპი",
    "Invalid image" : "არასწორი სურათი",
    "An error occurred. Please contact your admin." : "წარმოიშვა შეცდომა. გთხოვთ დაუკავშირდეთ თქვენს ადმინისტრატორს.",
    "No temporary profile picture available, try again" : "დროებითი პროფილის სურათი არაა ხელმისაწვდომი, სცადეთ ახლიდან",
    "No crop data provided" : "ამოჭრის მონაცემები არაა უზრუნველყოფილი",
    "No valid crop data provided" : "სწორი ამოჭრის მონაცემები არაა უზრუნველყოფილი",
    "Crop is not square" : "ამონაჭერი არაა კვადრატი",
    "State token does not match" : "მდგომარეობის ტოკენი არ ემთხვევა",
    "Password reset is disabled" : "პაროლის განახლება გამორთულია",
    "Couldn't reset password because the token is invalid" : "არასწორი ტოკენის გამო პაროლის აღდგენა ვერ მოხერხდა",
    "Couldn't reset password because the token is expired" : "ვადაგასული ტოკენის გამო პაროლის აღდგენა ვერ მოხერხდა",
    "%s password reset" : "%s პაროლის აღდგენა",
    "Password reset" : "პაროლის აღდგენა",
    "Click the following button to reset your password. If you have not requested the password reset, then ignore this email." : "პაროლის აღსადგენად დააჭირეთ შემდეგ ღილაკს. იმ შემთხვავაში თუ არ მოგითხოვიათ პაროლის აღდგენა, არ მიაქციოთ ყურადღება ამ წერილს.",
    "Click the following link to reset your password. If you have not requested the password reset, then ignore this email." : "პაროლის აღსადგენად დააჭირეთ შემდეგ ღილაკს. იმ შემთხვავაში თუ არ მოგითხოვიათ პაროლის აღდგენა, არ მიაქციოთ ყურადღება ამ წერილს.",
    "Reset your password" : "აღადგნიეთ თქვენი პაროლი",
    "Preparing update" : "განახლების მომზადება",
    "[%d / %d]: %s" : "[%d / %d]: %s",
    "Please use the command line updater because automatic updating is disabled in the config.php." : "ავტომატური განახლება config.php-ში გათიშულია, გთხოვთ ისარგებლოთ command-line განახლებით.",
    "[%d / %d]: Checking table %s" : "[%d / %d]: მოწმდება ცხრილი %s",
    "Turned on maintenance mode" : "სარემონტო რეჟიმი ჩაირთო",
    "Turned off maintenance mode" : "სარემონტო რეჟიმი გაითიშა",
    "Maintenance mode is kept active" : "სარემონტო რეჟიმი დარჩა აქტიური",
    "Updating database schema" : "მონაცემთა ბაზის სქემის განახლება",
    "Updated database" : "მონაცემთა ბაზის განახლება",
    "Checking whether the database schema can be updated (this can take a long time depending on the database size)" : "მოწმდება შესაძლებელია თუ არა მონაცემთა ბაზის სქემის განახლება (მონაცემთა ბაზის ზომასთან დამოკიდებულებით, ამ პროცესმა შეიძლება გასტანოს გარკვეული პერიოდი)",
    "Checked database schema update" : "შემოწმდა მონაცემთა ბაზის სქემის განახლება",
    "Checking updates of apps" : "მოწმდება აპლიკაციის განახლებები",
    "Checking for update of app \"%s\" in appstore" : "Appstore-ში მოწდება აპლიკაციის \"%s\" განახლება",
    "Update app \"%s\" from appstore" : "Appstore-იდან ნახლდება აპლიკაცია \"%s\"",
    "Checked for update of app \"%s\" in appstore" : "Appstore-ში დამოწმდა აპლიკაციის \"%s\" განახლება",
    "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "მოწმდება შესაძლებელია თუ არა %s-ისთვის მონაცემთა ბაზის სქემის განახლება (მონაცემთა ბაზის ზომასთან დამოკიდებულებით, ამ პროცესმა შეიძლება გასტანოს გარკვეული პერიოდი)",
    "Checked database schema update for apps" : "დამოწმდა აპლიკაციებისთვის მონაცემთა ბაზის სქემის განახლება",
    "Set log level to debug" : "ლოგის დონის დაყენება დებაგზე",
    "Reset log level" : "ლოგის დონის დაყენება საწყის პარამეტრზე",
    "Starting code integrity check" : "კოდის ერთიანობის შემოწმების დაწყება",
    "Finished code integrity check" : "დასრულდა კოდის ერთიანობის შემოწმება",
    "%s (incompatible)" : "%s (არაა თავსებადი)",
    "Following apps have been disabled: %s" : "შემდეგი აპლიკაციები გაითიშა: %s",
    "Already up to date" : "უკვე განახლებულია",
    "Very weak password" : "ძალიან სუსტი პაროლი",
    "Weak password" : "სუსტი პაროლი",
    "So-so password" : "არცთუ ისეთი ძლიერი პაროლი",
    "Good password" : "კარგი პაროლი",
    "Strong password" : "ძლიერი პაროლი",
    "Your web server is not yet properly set up to allow file synchronization, because the WebDAV interface seems to be broken." : "ფაილის სინქრონიზაციის დასაშვებად თქვენი ვებ-სერვერი ჯერ არაა სწორად კოფინგირურებული, როგორც ჩანს WebDAV ინტერფეისი გაფუჭებულია.",
    "Your web server is not properly set up to resolve \"{url}\". Further information can be found in the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentation</a>." : "\"{url}\"-ის გასახსნელად თქვენი ვებ-სერვერი არაა სწორად კონფიგურირებული. შეგიძლიათ იხილოთ მეტი ინფორმაცია <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">დოკუმენტაციაში</a>.",
    "PHP does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "როგორც ჩანს PHP სისტემის გარემოს ცვლადების მიღებისთვის არაა სწორად მოწყობილი. ეს ტესტი getenv(\"PATH\")-ით აბრუნებს მხოლოდ ცარიელ პასუხს.",
    "Your database does not run with \"READ COMMITTED\" transaction isolation level. This can cause problems when multiple actions are executed in parallel." : "თქვენი მონაცემთა ბაზა არ მოქმედებს \"READ COMMITTED\" ტრანზაქციის იზოლაციის დონით. ამან შეიძლება გამოიწვიოს პრობლემა, როდესაც მრავალი ქმედება შესრულდება პარალელურად.",
    "It was not possible to execute the cron job via CLI. The following technical errors have appeared:" : "CLI-ით კრონ საქმის ეგზეკუცია ვერ მოხერხდა. წარმოიშვა შემდეგი ტექნიკური შეცდომები:",
    "This server has no working Internet connection: Multiple endpoints could not be reached. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. Establish a connection from this server to the Internet to enjoy all features." : "ამ სერვერს არ გააჩნია მოქმედი ინტერნეტ კავშირი: მიუწვდომელია მრავალი წერტილი. ეს ნიშნავს, რომ ფუნქციები როგორებიცაა ექსტერნალური საცავის დაყენება, შეტყობინებები განახლებებზე ან მესამე მხარის აპლიკაციების ინსტალაცია არ იმუშავებს. შესაძლოა ფაილებთან დისტანციური წვდომა და საფოსტო შეტყობინებების გაგზავნაც არ მუშაობდეს. ყველა ფუნქციის მუშაობისთვის, ამ სერვერზე ჩართეთ ინტერნეტ კავშირი.",
    "No memory cache has been configured. To enhance performance, please configure a memcache, if available. Further information can be found in the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentation</a>." : "მეხსიერების კეში არაა კონფიგურირებული. მოქმედების მახასიათებლების გაუმჯობესებისთვის გთოხვთ გაუწიოთ კონფიგურაცია memcache-ს. შეგიძლიათ იხილოთ მეტი ინფორმაცია <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">დოკუმენტაციაში</a>.",
    "You are currently running PHP {version}. Upgrade your PHP version to take advantage of <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{phpLink}\">performance and security updates provided by the PHP Group</a> as soon as your distribution supports it." : "ამჟამად თქვენთან მოქმედია PHP {version}. განაახლეთ თქვენი PHP ვერსია, რათა ისარგებლოთ <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{phpLink}\">PHP Group-ის მიერ უზრუნველყოფილი გაუმჯობესებული ქმედებითა და უსაფრთხოებებისის განახლებებით</a>.",
    "You are currently running PHP 5.6. The current major version of Nextcloud is the last that is supported on PHP 5.6. It is recommended to upgrade the PHP version to 7.0+ to be able to upgrade to Nextcloud 14." : "თქვენთან ამ მომენტისთვის მოქმედია PHP 5.6. ამჟამინდელი Nextcloud-ის ძირითადი ვერსია ბოლოა, რომელიც მხარს უჭერს PHP 5.6-ს. Nextcloud 14-ზე განახლებისთვის, რეკომენდირებულია PHP განაახლოთ 7.0+ ვერსიამდე.",
    "The reverse proxy header configuration is incorrect, or you are accessing Nextcloud from a trusted proxy. If not, this is a security issue and can allow an attacker to spoof their IP address as visible to the Nextcloud. Further information can be found in the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentation</a>." : "Nextcloud-ს უკავშირდებით სანდო პქოქსით ან საწინააღმეგო პროქსის დასათაურებებების კონფიგურაცია არასწორია. თუ არა, ეს უსაფრთხოების პრობლემაა და თავდამსხმელმა შეიძლება მოიტყუოს IP მისამართით. იხილეთ მეტი ინფორმაცია ჩვენს <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">დოკუმენტაციაში</a>.",
    "Memcached is configured as distributed cache, but the wrong PHP module \"memcache\" is installed. \\OC\\Memcache\\Memcached only supports \"memcached\" and not \"memcache\". See the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{wikiLink}\">memcached wiki about both modules</a>." : "Memcached კონფიგურირებულია როგორც განაწილებული ქეში, თუმცა დაყენებულია არასწორი PHP მოდული \"memcache\" . \\OC\\Memcache\\Memcached მხარს უჭერს მხოლოდ \"memcached\"-ს და არა \"memcache\"-s. მეტი ინფორმაციისთვის იხილეთ <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{wikiLink}\">memcached ვიკი ორივე მოდულზე</a>.",
    "Some files have not passed the integrity check. Further information on how to resolve this issue can be found in the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentation</a>. (<a href=\"{codeIntegrityDownloadEndpoint}\">List of invalid files…</a> / <a href=\"{rescanEndpoint}\">Rescan…</a>)" : "გარკვეულმა ფაილება ვერ გაიარეს ერთიანობის შემოწმება. ინფორმაცია თუ როგორ აღმოფხრათ ეს პრობლემა შეგიძლიათ მოიძიოთ <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">დოკუმენტაციაში</a>. (<a href=\"{codeIntegrityDownloadEndpoint}\">არასწორი ფაილების სია...</a> / <a href=\"{rescanEndpoint}\">ხელახალი სკანირება...</a>)",
    "The PHP OPcache is not properly configured. <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">For better performance it is recommended</a> to use the following settings in the <code>php.ini</code>:" : "PHP OPcache არაა სწორად კონფიგურირებული. <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">უკეთესი მოქმედებისთვის რეკომენდირებულია</a> <code>php.ini</code>-ში გამოიყენოთ შემდეგი პარამეტრები:",
    "The PHP function \"set_time_limit\" is not available. This could result in scripts being halted mid-execution, breaking your installation. Enabling this function is strongly recommended." : "PHP-ს ფუნქცია \"set_time_limit\" არაა ხელმისაწვდომი. ამან შეიძლება ქმედებისას გამოიწვიოს სკრიპტების შეჩერება, ინსტალაციის შეწყვეტა. რეკომენდირებულია ამ ფუნქციის ჩართვა.",
    "Your PHP does not have FreeType support, resulting in breakage of profile pictures and the settings interface." : "თქვენს PHP-ს არ აქვს FreeType-ის მხარდაჭერა, რაც გამოწვევს დარღვეულ პროფილის სურათებს და პარამეტრების ინტერფეისს.",
    "SQLite is currently being used as the backend database. For larger installations we recommend that you switch to a different database backend." : "ამჟამად ბექენდზე მონაცემთა ბაზად მოიხმარება SQLite. უფრო დიდი ინსტალაციებისთვის რეკომენდაციას გიწევთ აირჩიოთ სხვა მონაცემთა ბაზა.",
    "This is particularly recommended when using the desktop client for file synchronisation." : "ეს კერძოდ რეკომედირებულია განსაკუთრებით მაშინ, როდესაც ფაილების სინქრონიზაციისთვის იყენებთ დესკტოპ-კლიენტს.",
    "Error occurred while checking server setup" : "შეცდომა სერვერის მოწყობის შემოწმებისას",
    "Your data directory and files are probably accessible from the Internet. The .htaccess file is not working. It is strongly recommended that you configure your web server so that the data directory is no longer accessible, or move the data directory outside the web server document root." : "თქვენი data დირექტორია და ფაილები ალბათ წვდომადია ინტერნეტიდან. .htaccess ფაილი არ მუშაობს. მკაცრად რეკომენდირებულია ისე გაუწიოთ თქვენს ვებ-სერვერს კონფიგურაცია, რომ data დირექტორია აღარ იყოს წვდომადი, ან გაიტანოთ ის ვებ-სერვერის root დირექტორიიდან.",
    "The \"{header}\" HTTP header is not set to \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "HTTP დასათაურება \"{header}\" არაა კონფიგურირებული უტოლდებოდეს \"{expected}\"-ს. ეს პოტენციური უსაფრთხოების და კონფიდენციალურობის რისკია, რეკომენდირებულია ამ პარამეტრის გამოსწორება.",
    "The \"{header}\" HTTP header is not set to \"{expected}\". Some features might not work correctly, as it is recommended to adjust this setting accordingly." : "HTTP დასათაურება \"{header}\" არაა კონფიგურირებული უტოლდებოდეს \"{expected}\"-ს. ზოგიერთმა ფუნქციამ შეიძლება არ იმუშაოს სწორად და რეკომენდირებულია ამ პარამეტრის რეგულაცია.",
    "Non-existing tag #{tag}" : "ტეგი #{tag} არ არსებობს",
    "restricted" : "აკრძალული",
    "invisible" : "უჩინარი",
    "({scope})" : "({scope})",
    "Delete" : "წაშლა",
    "Rename" : "სახელის შეცვლა",
    "Collaborative tags" : "ერთობლივი ტეგები",
    "No tags found" : "ტეგები ვერ იქნა ნაპოვნი",
    "unknown text" : "ამოუცნობი ტეგი",
    "Hello world!" : "გამარჯობა სამყარო!",
    "sunny" : "მზიანი",
    "Hello {name}, the weather is {weather}" : "გამარჯობა {name}, ამინდია {weather}",
    "Hello {name}" : "გამარჯობა {name}",
    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>ეს ძიების შედეგებია<script>alert(1)</script></strong>",
    "new" : "ახალი",
    "_download %n file_::_download %n files_" : ["ჩამოტვირთეთ %n ფაილი","ჩამოტვირთეთ %n ფაილი"],
    "The update is in progress, leaving this page might interrupt the process in some environments." : "განახლება პროცესშია, გარკვეულ გარემოებებში ამ გვერდის დატოვებამ შეიძლება შეწყვიტოს პროცესი.",
    "Update to {version}" : "განაახლეთ ვერსიაზე {version}",
    "An error occurred." : "წარმოიშვა შეცდომა.",
    "Please reload the page." : "გთხოვთ გადატვირთოთ გვერდი.",
    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "განახლებისას წარმოიშვა შეცდომა. მეტი ინფორმაციისთვის იხილეთ <a href=\"{url}\">ჩვენი ფორუმის პოსტი</a>, სადაც საუბარია ამ პრობლემაზე.",
    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "განახლებისას წარმოიშვა შეცდომა. გთხოვთ განაცხადოთ ამ პრობლემის შესახებ <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud საზოგადოებაში</a>.",
    "Continue to Nextcloud" : "გაგრძლება Nextcloud-ისკენ",
    "_The update was successful. Redirecting you to Nextcloud in %n second._::_The update was successful. Redirecting you to Nextcloud in %n seconds._" : ["განახლება წარმატებით დასრულდა. Nextcloud-ისკენ გადაგამისამართებთ %n წამში.","განახლება წარმატებით დასრულდა. Nextcloud-ისკენ გადაგამისამართებთ %n წამში."],
    "Searching other places" : "ვეძებთ დანარჩენ ადგილებში",
    "No search results in other folders for {tag}{filter}{endtag}" : "ძიების შედეგები სხვა დირექტორიებში {tag}{filter}{endtag}-სთვის არაა",
    "_{count} search result in another folder_::_{count} search results in other folders_" : ["{count} ძიების შედეგები სხვა დირექტორიებში","{count} ძიების შედეგები სხვა დირექტორიებში"],
    "Server side authentication failed!" : "სერვერის მხარეს აუტენტიფიკაცია ვერ მოხერხდა!",
    "Please contact your administrator." : "გთხოვთ დაუკავშირდეთ თქვენს ადმინისტრატორს.",
    "An internal error occurred." : "გამოჩნდა შიდა შეცდომა.",
    "Please try again or contact your administrator." : "გთხოვთ სცადოთ ახლიდან ან დაუკავშირდეთ თქვენს ადმინისტრატორს.",
    "Username or email" : "მომხმარებლის სახელი ან ელ-ფოსტა",
    "Password" : "პაროლი",
    "Log in" : "შესვლა",
    "Logging in …" : "შესვლა ...",
    "Wrong username or password." : "არასწორი მომხმარებლის სახელი ან პაროლი.",
    "User disabled" : "მომხმარებელი გათიშულია",
    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "თქვენი IP მისამართით შევნიშნეთ არაერთი წარუმატებელი ავტორიზაციის მცდელობა. აქედან გამომდინარე თქვენი შემდეგი ავტორიზაციის მცდელობა შეიზღუდება დაახლოებით 30 წამით.",
    "Reset password" : "პაროლის შეცვლა",
    "Couldn't send reset email. Please contact your administrator." : "აღდგენის ელ-წერილი ვერ გაიგზავნა. გთხოვთ დაუკავშირდეთ თქვენს ადმინისტრატორს.",
    "Password can not be changed. Please contact your administrator." : "პაროლი ვერ იცვლება. დაუკავშირდით თქვენს ადმინისტრატორს.",
    "New password" : "ახალი პაროლი",
    "I know what I'm doing" : "ვიცი რასაც ვაკეთებ",
    "Cancel" : "უარყოფა",
    "Forgot password?" : "დაგავიწყდათ პაროლი?",
    "Settings" : "პარამეტრები",
    "Could not load your contacts" : "თქვენი კონტაქტების ჩატვირთვა ვერ მოხერხდა",
    "Search contacts …" : "მოძებნეთ კონტაქტები ...",
    "No contacts found" : "კომენტარები ვერ იქნა ნაპოვნი.",
    "Show all contacts …" : "ყველა კონტაქტის ჩვენება ...",
    "Loading your contacts …" : "იტვირთება კონტაქტები ...",
    "Looking for {term} …" : "ვეძებთ {term}-ს …",
    "No" : "არა",
    "Yes" : "კი",
    "No files in here" : "აქ ფაილები არაა",
    "New folder" : "ახალი დირექტორია",
    "Name" : "სახელი",
    "Size" : "ზომა",
    "Modified" : "შეიცვალა",
    "{newName} already exists" : "{newName} უკვე არსებობს",
    "Choose" : "არჩევა",
    "Copy" : "კოპირება",
    "Move" : "გადატანა",
    "Error loading file picker template: {error}" : "შეცდომა ფაილის შაბლონის ჩატვირთვისას: {error}",
    "OK" : "კარგი",
    "Error loading message template: {error}" : "შეცდომა წერილის შაბლონის ჩატვირთვისას: {error}",
    "read-only" : "მხოლოდ-კითხვადი",
    "_{count} file conflict_::_{count} file conflicts_" : ["{count} ფაილის კონფლიქტი","{count} ფაილის კონფლიქტი"],
    "One file conflict" : "კონფლიქტი ერთ ფაილთან",
    "New Files" : "ახალი ფაილები",
    "Already existing files" : "უკვე არსებული ფაილები",
    "Which files do you want to keep?" : "რომელი ფაილების დატოვება გსურთ?",
    "If you select both versions, the copied file will have a number added to its name." : "თუ აირჩევთ ორივე ვერსიას, კოპირებულ ფაილს სახელის წინ დაერთვება ციფრი.",
    "Continue" : "გაგრძელება",
    "(all selected)" : "(ყველა არჩეული)",
    "({count} selected)" : "({count} არჩეული)",
    "Error loading file exists template" : "ფაილის ჩატვირთვისას წარმოიშვა შეცდომა",
    "Pending" : "მოლოდინში",
    "Copy to {folder}" : "კოპრება {folder}-ში",
    "Move to {folder}" : "გადატანა {folder}-ში",
    "Saving..." : "შენახვა...",
    "Authentication required" : "საჭიროა აუტენტიფიკაცია",
    "This action requires you to confirm your password" : "ეს ქმედება საჭიროებს პაროლის დადასტურებას",
    "Confirm" : "დადასტურება",
    "Failed to authenticate, try again" : "აუტენტიფიკაცია ვერ შესრულდა, სცადეთ ახლიდან",
    "seconds ago" : "წამის წინ",
    "Connection to server lost" : "სერვერთან კავშირი დაიკარგა",
    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["გვერდის ჩატვირთვის პროლბემა, ხელახალი ჩატვირთვა მოხდება %n წამში","გვერდის ჩატვირთვის პროლბემა, ხელახალი ჩატვირთვა მოხდება %n წამში"],
    "Hide details" : "დეტალების დამალვა",
    "No action available" : "ქმედება არაა ხელმისაწვდომი",
    "Error fetching contact actions" : "კონტაქტის ქმედებების მოხვეწისას წარმოიქმნა შეცდომა",
    "Personal" : "პირადი",
    "Users" : "მომხმარებელი",
    "Apps" : "აპლიკაციები",
    "Admin" : "ადმინისტრატორი",
    "Help" : "დახმარება",
    "Access forbidden" : "წვდომა აკრძალულია",
    "File not found" : "ფაილი ვერ იქნა ნაპოვნი",
    "Error" : "შეცდომა",
    "Internal Server Error" : "შიდა სერვერის შეცდომა",
    "The server was unable to complete your request." : "სერვერმა ვერ დაასრულა თქვენი მოთხოვნა.",
    "If this happens again, please send the technical details below to the server administrator." : "თუ ეს განმეორდება, გთხოვთ გაუგზავნოთ ქვემოთ აღწერილი ტექნიკური დეტალები თქვენი სერვერის ადმინისრატორს.",
    "More details can be found in the server log." : "მეტი დეტალები შეგიძლიათ იხილოთ სერვერის ლოგში.",
    "Technical details" : "ტექნიკური დეტალები",
    "Remote Address: %s" : "დისტანციური მისამართი: %s",
    "Request ID: %s" : "მოთხოვნის ID: %s",
    "Type: %s" : "ტიპი: %s",
    "Code: %s" : "კოდი: %s",
    "Message: %s" : "წერილი: %s",
    "File: %s" : "ფაილი: %s",
    "Line: %s" : "ხაზი: %s",
    "Trace" : "კვალი",
    "Security warning" : "გაფრთხილება უსაფრთხოების შესახებ",
    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "თქვენი ფაილები და მონაცემების დირექტორია ინტერნეტით წვდომადია, რადგან .htaccess ფაილი არ მუშაობს.",
    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "ინფორმაციისთვის თუ როგორ გაუწიოთ სერვერს სწორი კონფიგურაცია იხილეთ <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">დოკუემტაცია</a>.",
    "Create an <strong>admin account</strong>" : "შექმენით <strong>ადმინისტრატორის ანგარიში</strong>",
    "Username" : "მომხმარებლის სახელი",
    "Storage & database" : "საცავი და მონაცემთა ბაზა",
    "Data folder" : "მონაცემთა დირექტორია",
    "Configure the database" : "მონაცემთა ბაზის კონფიგურაცია",
    "Only %s is available." : "მხოლოდ %s-ია ხელმისაწვდომი.",
    "Install and activate additional PHP modules to choose other database types." : "სხვა მონაცემთა ბაზის სახეობებისთვის დააყენეთ და გაააქტიურეთ დამატებითი PHP მოდულები.",
    "For more details check out the documentation." : "მეტი დეტალებისთვის იხილეთ დოკუმენტაცია.",
    "Database user" : "მონაცემთა ბაზის მომხმარებელი",
    "Database password" : "მონაცემთა ბაზის პაროლი",
    "Database name" : "მონაცემთა ბაზის სახელი",
    "Database tablespace" : "ბაზის ცხრილის ზომა",
    "Database host" : "მონაცემთა ბაზის ჰოსტი",
    "Please specify the port number along with the host name (e.g., localhost:5432)." : "ჰოსტის სახელთან ერთად გთხოვთ მიუთითოთ პორტის ნომერიც (მაგ.: localhost:5432).",
    "Performance warning" : "გაფრთხილება მოქმედების შესახებ",
    "Finish setup" : "კონფიგურაციის დასრულება",
    "Finishing …" : "სრულდება ...",
    "Need help?" : "გესაჭიროებათ დახმარება?",
    "See the documentation" : "იხილეთ დოკუმენტაცია",
    "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "ეს აპლიკაცია სწორი ოპერაციისთვის საჭიროებს JavaScript-ს. გთხოვთ {linkstart}ჩართოთ JavaScript-ი{linkend} და გადატვირთოთ გვერდი.",
    "More apps" : "მეტი აპლიკაცია",
    "More" : "მეტი",
    "Search" : "ძებნა",
    "Reset search" : "ძიების შედეგები",
    "Contacts" : "კონტაქტები",
    "Confirm your password" : "დაადასტურეთ თქვენი პაროლი",
    "App token" : "აპლიკაციის ტოკენი",
    "Grant access" : "უფლებების მინიჭება",
    "Account access" : "წვდომა ანგარიშზე",
    "This share is password-protected" : "ეს გაზიარება დაცულია პაროლით",
    "The password is wrong. Try again." : "პაროლი არასწორია. სცადეთ ახლიდან.",
    "Two-factor authentication" : "ორ-ფაქტრიანი აუტენტიფიკაცია",
    "Use backup code" : "ბექაფის კოდის გამოყენება",
    "Error while validating your second factor" : "მეორე ფაქტორის ვალიდაციისას წარმოიშვა შეცდომა",
    "Access through untrusted domain" : "წვდომა არა-სანდო დომენიდან",
    "Please contact your administrator. If you are an administrator, edit the \"trusted_domains\" setting in config/config.php like the example in config.sample.php." : "გთხოვთ დაუკავშირდეთ თქვენს ადმინისტრატორს. იმ შემთხვევაში თუ ბრძანდებით ადმინისტრატორი, config/config.php-ში შეცვალეთ \"trusted_domains\" პარამეტრი, ისე როგორც ნაჩვენებია მაგალითში config.sample.php.",
    "App update required" : "აპლიკაციას ესაჭიროება განახლება",
    "These apps will be updated:" : "ეს აპლიკაციები განახლდება:",
    "These incompatible apps will be disabled:" : "ეს არათავსებადი აპლიკაციები წაიშლება:",
    "The theme %s has been disabled." : "ვიზუალური თემა %s გაითიშა.",
    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "გაგრძელებმდე გთხოვთ დარწმუნდეთ, რომ მონაცემთა ბაზას, კონფიგურაციის დირექტორიას და მონაცემთა დირექტორიას ჩაუტარდა ბექაფი.",
    "Start update" : "განახლების დაწყება",
    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "დიდ ინსტალაციებთან მუშაობისას დროის ამოწურვის შეცდომების თავიდან აცილებისთვის, შეგიძლიათ გაუშვათ შემდეგი ბრძანება ინსტალაციის დირექტორიაში:",
    "Detailed logs" : "დეტალური ლოგები",
    "Update needed" : "საჭიროა განახლება",
    "Please use the command line updater because you have a big instance with more than 50 users." : "გთხოვთ მოიხმაროთ \"command-line\" განმანახლებელი რადგანაც ეს დიდი ინსტანციაა, მასზე 50-ზე მეტი მომხმარებელია.",
    "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>." : "დახმარებისთვის  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">იხილეთ დოკუმენტაცია</a>.",
    "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "ვიცი რომ, თუ გავაგრძელებ განახლებას ვებ-ინტერფეისით, არის რისკი, რომ მოთხოვნას დრო ამოეწურება და შეიძლება მოხდეს მონაცემების დაკარგვა, თუმცა მაქვს ბექაფი და ვიცი თუ როგორ აღვადგინო ინსტანცია იმ შემთხვევაში თუ მოხდება შეცდომა.",
    "Upgrade via web on my own risk" : "ვებით განაახლეთ თქვენი პასუხისმგებლობით",
    "This %s instance is currently in maintenance mode, which may take a while." : "ეს %s ინსტანცია ამჟამად სარემონტო რეჟიმშია, ამან შეიძლება გასტანოს გარკვეული დრო.",
    "Contact your system administrator if this message persists or appeared unexpectedly." : "თუ ეს წერილი გამოჩნდა მოულოდნელად ან მისი გამოჩენა გრძელდება, დაუკავშირდით სისტემის ადმინისტრატორს.",
    "Could not send reset email because there is no email address for this username. Please contact your administrator." : "ამ მომხმარებლისთვის ელ-ფოსტის მისამართი არაა დაყენებული, შესაბამისად აღდგენის ელ-წერილი ვერ გაიგზავნა. გთხოვთ დაუკავშირდეთ თქვენს ადმინისტრატორს.",
    "Couldn't send reset email. Please make sure your username is correct." : "აღდგენის ელ-წერილი ვერ გაიგზავნა. დარწმუნდით, რომ მომხმარებლის სახელი სწორია.",
    "Dismiss" : "დათხოვნა",
    "The link to reset your password has been sent to your email. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator." : "ბმული პაროლის აღდგენით თქვენს ელ-ფოსტაზე გაგზავნილია. თუ გავიდა გარკვეული დრო და მაინც არ მოგსვლიათ, შეამოწმეთ სპამის დირექტორიაც.<br>თუ მაინც ვერ მიაგენით მიმართეთ ლოკალურ ადმინისტრატორს.",
    "Your files are encrypted. There will be no way to get your data back after your password is reset.<br />If you are not sure what to do, please contact your administrator before you continue. <br />Do you really want to continue?" : "ფაილები კოდირებულია. პაროლის აღდგენის შემდეგ ვერანაირად ვერ დაიბრუნებთ მონაცემებს.<br />თუ არ ხართ დარწმუნებული რა გააკეთოთ, გაგრძელებამდე მიმართეთ თქვენს ადმინისტრატორს.<br />დარწმუნებული ხართ, რომ გსურთ გაგრძელება?",
    "Sending email …" : "წერილი იგზავნება ...",
    "Shared" : "გაზიარებული",
    "Shared with" : "გაზიარებულია",
    "Shared by" : "გამზიარებელი",
    "Choose a password for the public link" : "საზოგადო ბმულისთვის აირჩიეთ პაროლი",
    "Choose a password for the public link or press the \"Enter\" key" : "აირჩიეთ პაროლი საზოგადო ბმულისთვის ან დააჭირეთ \"Enter\"-ს",
    "Copied!" : "კოპირებულია!",
    "Copy link" : "ბმულის კოპირება",
    "Not supported!" : "არაა მხარდაჭერილი!",
    "Press ⌘-C to copy." : "დასაკოპირებლად დააჭირეთ ⌘-C-ს",
    "Press Ctrl-C to copy." : "დასაკოპირებლად დააჭირეთ Ctrl-C-ს",
    "Resharing is not allowed" : "ხელახალი გაზიარება არაა დაშვებული",
    "Link" : "ბმული",
    "Password protect" : "პაროლით დაცვა",
    "Allow editing" : "ცვლილების უფლების მინიჭება",
    "Email link to person" : "ბმულის პიროვნების ელ-მისამართზე გაგზავნა",
    "Send" : "გაგზავნა",
    "Allow upload and editing" : "ატვირთვისა და ცვლილების უფლებების მინიჭება",
    "Read only" : "მხოლოდ-კითხვადი",
    "File drop (upload only)" : "ფაილის ჩაგდება (მხოლოდ ატვირთვა)",
    "Set expiration date" : "მიუთითეთ ვადის გასვლის დრო",
    "Expiration" : "ვადის გასვლა",
    "Expiration date" : "ვადის გასვლის დრო",
    "Unshare" : "გაზიარების შეწყვეტა",
    "Share to {name}" : "გაუზიარეთ მომხმარებელს {name}",
    "Share link" : "გააზიარეთ ბმული",
    "Could not unshare" : "გაზიარების შეწყვეტა ვერ მოხერხდა",
    "Shared with you and the group {group} by {owner}" : "თქვენ და {group} ჯგუფს გაგიზიარდათ მომხმარებლისგან {owner}",
    "Shared with you by {owner}" : "თქვენთან გაზიარდა მომხმარებლისგან {owner}",
    "Choose a password for the mail share" : "აირჩიეთ პაროლი ელ-ფოსტით გაზიარებისთვის",
    "group" : "ჯგუფი",
    "remote" : "დისტანციური",
    "email" : "ელ-ფოსტა",
    "shared by {sharer}" : "გააზიარა მომხმარებელმა {sharer}",
    "Can reshare" : "შეუძლია ხელახალი გაზიარება",
    "Can edit" : "შეუძლია შეცვლა",
    "Can create" : "შეუძლია შექმნა",
    "Can change" : "შეუძლია ცვლილება",
    "Can delete" : "შეუძლია გაუქმება",
    "Access control" : "დაშვების კონტროლი",
    "Error while sharing" : "შეცდომა გაზიარების დროს",
    "Share details could not be loaded for this item." : "ამ ობიექტისთვის გაზიარების დეტალები ვერ ჩაიტვირთა.",
    "_At least {count} character is needed for autocompletion_::_At least {count} characters are needed for autocompletion_" : ["ავტო-დასრულებისთვის საჭიროა მინიმუმ {count} სიბმოლო","ავტო-დასრულებისთვის საჭიროა მინიმუმ {count} სიბმოლო"],
    "This list is maybe truncated - please refine your search term to see more results." : "ეს სია შეიძლება იყოს წაკვეთილი - მეტი შედეგისთვის, გთხოვთ გაწმინდოთ თქვენი საძიებო სიტყვა.",
    "No users or groups found for {search}" : "მომხმარებლები და ჯგუფები {search}-ისთვის არ იქნა ნაპოვნი",
    "No users found for {search}" : "მომხმარებლები {search}-ისთვის არ იქნა ნაპოვნი",
    "An error occurred. Please try again" : "წარმოიშვა შეცდომა. გთხოვთ სცადოთ ახლიდან.",
    "Home" : "სახლი",
    "Work" : "სამსახური",
    "Other" : "სხვა",
    "{sharee} ({type}, {owner})" : "{sharee} ({type}, {owner})",
    "Share" : "გაზიარება",
    "Name or email address..." : "სახელი ან ელ-ფოსტის მისამართი...",
    "Name or federated cloud ID..." : "სახელი ან ფედერალური ქლაუდ ID",
    "Name, federated cloud ID or email address..." : "სახელი, ფედერალური ქლაუდ ID ან ელ-ფოსტის მისამართი",
    "Name..." : "სახელი...",
    "Error removing share" : "გაზიარების გაუქმებისას წარმოიშვა შეცდომა",
    "SQLite will be used as database." : "მონაცემთა ბაზად მოხმარებულ იქნება SQLite.",
    "For larger installations we recommend to choose a different database backend." : "უფრო დიდი ინსტალაციებისთვის რეკომენდაციას გიწევთ აირჩიოთ სხვა მონაცემთა ბაზა.",
    "Especially when using the desktop client for file syncing the use of SQLite is discouraged." : "SQLite-ის გამოყენება არაა რეკომედირებული განსაკუთრებით მაშინ, როდესაც ფაილების სინქრონიზაციისთვის იყენებთ დესკტოპ-კლიენტს.",
    "Wrong password." : "არასწორი პაროლი.",
    "New Password" : "ახლი პაროლი",
    "Cancel log in" : "ავტორიზაციის შეჩერება"
},
"nplurals=2; plural=(n!=1);");
